/**************************************************************************
 *   Copyright (C) 2022 David Register                                     *
 *   Copyright (C) 2022 Alec Leamas                                        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,  USA.         *
 **************************************************************************/

/**
 *  \file
 *  NMEA0183 drivers common base.
 */

#ifndef _COMMDRIVERN0183_H__
#define _COMMDRIVERN0183_H__

#include <memory>
#include <string>

#include "model/comm_driver.h"

/** NMEA0183 drivers common part. */
class CommDriverN0183 : public AbstractCommDriver {
public:
  CommDriverN0183();
  CommDriverN0183(NavAddr::Bus b, const std::string& s);

  virtual ~CommDriverN0183();

  virtual bool SendMessage(std::shared_ptr<const NavMsg> msg,
                           std::shared_ptr<const NavAddr> addr) override = 0;

  void SetListener(DriverListener& l) override {}

  virtual std::shared_ptr<NavAddr> GetAddress() {
    return std::make_shared<NavAddr>(NavAddr0183(iface));
  }
};

#endif  // guardstring
